# HCMS RT-UI

## Prerequisites

#### User mode

As a developer if you want to install the package in a different React project you will need to have the following packages mentioned in your dependencies

`React >17`
`@material-ui/core`
`@material-ui/lab` (recommended)
`@material-ui/icons` (recommended)

Is recommended to also use `yarn` as a package dependencies manager, but you can use `npm` as well.

Install the dependencies

`yarn add react @material-ui/core @material-ui/lab @material-ui/icons`

`npm i -s react @material-ui/core @material-ui/lab @material-ui/icons`

#### Contribute mode

To contribute to the project you will have to use `yarn` as your dependencies manager, and have `node >12` installed.

If you use `nvm` as your node version manager run

`nvm use v12`

## Contribute

### Install correct dependencies and init the project

The project can be initialized with two different sets of dependencies depending on if you want to run the application or Storybook OR if you want to create a production build to be published as an npm package

#### Init project for development (React or Storybook)

`yarn init-sb`

### Run as a React App Locally

To run the application locally run

`yarn init-sb` (if not done already)

`yarn start`

### Run Storybook Locally

To run Storybook locally run

`yarn init-sb` (if not done already)

`yarn storybook`

### Build Storybook

To run Storybook locally run

`yarn init-sb` (if not done already)

`yarn build-storybook`

The build folder is `storybook-static`
To test it locally, you can run the following command

`npm i -g serve`
`serve storybook-static`

### Install additional dependencies

To install a new dependency on the package

`yarn add {your-dependency}`

After the installation is completed check the new dependency mentioned in your `package.json` and report it in the two `package.json` templates:

`package.sb.json`
`package.pkg.json`

!!! DO NOT COPY PASTE THE ENTIRE SET OF DEPENDENCIES FROM YOUR PACKAGE.JSON TO THE TEMPLATE, BUT ONLY THE NEW ONE YOU INSTALLED !!!

### Updates to package.json

Note: every change you want to do to the project package.json needs to be reflected to the two template files
`package.sb.json`
`package.pkg.json`

Otherwise your changes will be reverted at the next build process.

### Build NPM Package

Before the build you might want to update the package version in your

`package.sb.json`
`package.pkg.json`

!!! DO NOT MANUALLY UPDATE YOUR PACKAGE.JSON FILE AS IT WILL BE AUTOMATICALLY REGENERATED AT BUILD TIME FROM .SB AND .PKG ACCORDING TO THE BUILD TYPE !!!

To create a production build to be published to the private registry run

`yarn init-pkg` (if not done already)

`yarn build-pkg`

### Publish NPM Package

To publish the package to the RT npm registry run

`npm publish`

Note: the instructions mentioned in the `package.json` and in the `.npmrc` will instruct the publisher to the correct _private_ registry and will authenticate using the auth token.
If the auth token has expired you might need to generate a new auth token and change it in your .npmrc file to be able to publish

### Usefull links

https://docs.gitlab.com/ee/user/packages/npm_registry/

## User Mode

### Package Link

https://gitlab.raketech.com/headless-cms/hcms-components-library/-/packages

### Install NPM Package on a React Project

In order to install the package in your new project you will need to instruct npm to get the package from the correct registry, to do so:

create a new `.npmrc` file in the root of your project with the following content

```

@headless-cms:registry=https://gitlab.raketech.com/api/v4/packages/npm/
//gitlab.raketech.com/api/v4/projects/:_authToken={YOUR-ACCESS-TOKEN}

```

Replace {YOUR-ACCESS-TOKEN} with your token

IF you are using `yarn` you might need to additionally instruct Yarn, to do that add a `.yarnrc` file to the root of your project

```

"@headless-cms:registry" "https://gitlab.raketech.com/api/v4/packages/npm/"

```

If you encounter the following error

`error Couldn't find package "@headless-cms/rt-ui" on the "npm" registry.`

Try to add the following line at the end of your `~/.npmrc`

```

//gitlab.raketech.com/api/v4/projects/:_authToken={YOUR-ACCESS-TOKEN}

```

If encounter other issues check the troubleshoot at the following link
https://gitlab.raketech.com/help/user/packages/npm_registry/index#troubleshooting

Install the library using

`yarn add @headless-cms/rt-ui`
or
`npm i -s @headless-cms/rt-ui`

### How to use the components

The only think you will need to do in order for the library to work properly and reflect your sites style is yo wrap your entire application with the provided `ThemeProvider`component and pass a `Theme`object generated with `createTheme` from @material-ui

```tsx
import { Container, createTheme } from '@material-ui/core';
import { Button, Header, ThemeProvider } from '@headless-cms/rt-ui';

const theme = createTheme({
  palette: {
    primary: {
      main: '#ff0000',
    },
  },
});

function App() {
  return (
    <Container>
      <ThemeProvider theme={theme}>
        <Header color="primary">asdasd</Header>
        <Button variant="contained" color="primary">
          Click me
        </Button>
      </ThemeProvider>
    </Container>
  );
}
```

### Useful links

https://gitlab.raketech.com/help/user/packages/npm_registry/index
